@@ -732,6 +732,7 @@ class SessionStore(object):
         value (str): A Session ID as str
         created (int): seconds as epoch when a session_id record was created
         expires (int): seconds as epoch when a session_id record expires
+        is_legacy (bool): whether the Session ID is for an older OTRS Version (<=7)
 
     Raises:
         ArgumentMissingError
@@ -739,7 +740,7 @@ class SessionStore(object):
     """
 
     def __init__(self, file_path=None, session_timeout=None,
-                 value=None, created=None, expires=None):
+                 value=None, created=None, expires=None, is_legacy=False):
         if not file_path:
             raise ArgumentMissingError("Argument file_path is required!")
 
@@ -751,6 +752,7 @@ class SessionStore(object):
         self.value = value
         self.created = created
         self.expires = expires
+        self.is_legacy = is_legacy
 
     def __repr__(self):
         return "<{0}: {1}>".format(self.__class__.__name__, self.file_path)
@@ -773,9 +775,10 @@ class SessionStore(object):
         try:
             data = json.loads(content)
             self.value = data['session_id']
+            self.is_legacy = data.get('is_legacy', False)
 
             self.created = datetime.datetime.utcfromtimestamp(int(data['created']))
-            self.expires = (self.created + datetime.timedelta(minutes=self.timeout))
+            self.expires = (self.created + datetime.timedelta(seconds=self.timeout))
 
             if self.expires > datetime.datetime.utcnow():
                 return self.value  # still valid
@@ -803,7 +806,8 @@ class SessionStore(object):
 
         with open(self.file_path, 'w') as f:
             f.write(json.dumps({'created': str(int(time.time())),
-                                'session_id': self.value}))
+                                'session_id': self.value,
+                                'is_legacy': self.is_legacy}))
         os.chmod(self.file_path, 384)  # 384 is '0600'
 
         # TODO 2016-04-23 (RH): check this
@@ -919,10 +923,12 @@ class Client(object):
 
         if not session_id_file:
             self.session_id_store = SessionStore(file_path="/tmp/.pyotrs_session_id",
-                                                 session_timeout=self.session_timeout)
+                                                 session_timeout=self.session_timeout,
+                                                 is_legacy=use_legacy_sessions)
         else:
             self.session_id_store = SessionStore(file_path=session_id_file,
-                                                 session_timeout=self.session_timeout)
+                                                 session_timeout=self.session_timeout,
+                                                 is_legacy=use_legacy_sessions)
 
         self.session_validation_ticket_id = session_validation_ticket_id
 
@@ -1078,6 +1084,7 @@ class Client(object):
             if not self.use_legacy_sessions:
                 log.warning("AccessTokenCreate failed, retrying using legacy session")
                 self.use_legacy_sessions = True
+                self.session_id_store.is_legacy = True
                 return self.session_create()
             return False
 
@@ -1128,6 +1135,8 @@ class Client(object):
             if self.session_get(self.session_id_store.value):
                 log.info("Using valid Session ID "
                          "from ({0})".format(self.session_id_store.file_path))
+                # update legacy session with info from store
+                self.use_legacy_sessions = self.session_id_store.is_legacy
                 return True
 
         # got no (valid) session_id; clean store
@@ -1222,7 +1231,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "TicketCreate"
 
         payload = {self._session_key: self.session_id_store.value}
@@ -1284,7 +1293,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "TicketGet"
 
         payload = {
@@ -1326,7 +1335,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "TicketGetList"
 
         if not isinstance(ticket_id_list, list):
@@ -1423,7 +1432,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "TicketSearch"
         payload = {
             self._session_key: self.session_id_store.value,
@@ -1494,7 +1503,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "TicketUpdate"
 
         payload = {self._session_key: self.session_id_store.value, "TicketID": ticket_id}
@@ -1562,7 +1571,7 @@ class Client(object):
         """faq_language_list"""
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "LanguageList"
 
         payload = {
@@ -1579,7 +1588,7 @@ class Client(object):
         """faq_public_category_list"""
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "PublicCategoryList"
 
         payload = {
@@ -1606,7 +1615,7 @@ class Client(object):
 
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "PublicFAQGet"
 
         payload = {
@@ -1658,7 +1667,7 @@ class Client(object):
 
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "PublicFAQSearch"
 
         payload = {
@@ -1717,7 +1726,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "LinkAdd"
 
         payload = {
@@ -1760,7 +1769,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "LinkDelete"
 
         payload = {
@@ -1795,7 +1804,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "LinkDeleteAll"
 
         payload = {
@@ -1837,7 +1846,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "LinkList"
 
         payload = {
@@ -1872,7 +1881,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "PossibleLinkList"
 
         payload = {
@@ -1903,7 +1912,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "PossibleObjectsList"
 
         payload = {
@@ -1938,7 +1947,7 @@ class Client(object):
         """
         if not self.session_id_store.value:
             raise SessionNotCreated("Call session_create() or "
-                                    "session_restore_or_set_up_new() first")
+                                    "session_restore_or_create() first")
         self.operation = "PossibleTypesList"
 
         payload = {
